@@ -7,7 +7,7 @@ from typing import Any, List, NoReturn, Optional, Tuple, Union
 
 from .argparse import ArgumentParserWithUnknowns
 from .config import PikaurConfig
-from .i18n import _, _n
+from .i18n import translate, translate_many
 
 
 ArgSchema = List[Tuple[Optional[str], str, Union[None, bool, str, int]]]
@@ -72,7 +72,7 @@ PACMAN_STR_OPTS: ArgSchema = [
     ('r', 'root', None),
     (None, 'arch', None),  # @TODO
     (None, 'cachedir', None),  # @TODO
-    (None, 'config', None),  # @TODO
+    (None, 'config', None),
     (None, 'gpgdir', None),
     (None, 'hookdir', None),
     (None, 'logfile', None),
@@ -152,7 +152,7 @@ class PikaurArgs(Namespace):
         return getattr(super(), name, getattr(self, name.replace('-', '_')))
 
     def handle_the_same_letter(self) -> None:
-        # pylint: disable=attribute-defined-outside-init,access-member-before-definition
+        # pylint: disable=attribute-defined-outside-init
         if self.pkgbuild and self.info:  # handle "-i"
             self.install = self.info
             self.info = False
@@ -168,7 +168,7 @@ class PikaurArgs(Namespace):
                 self.check = None
 
     def post_process_args(self) -> None:
-        # pylint: disable=attribute-defined-outside-init,access-member-before-definition
+        # pylint: disable=attribute-defined-outside-init
         self.handle_the_same_letter()
 
         new_ignore: List[str] = []
@@ -354,13 +354,13 @@ def parse_args(args: List[str] = None) -> PikaurArgs:
     try:
         parsed_args.validate()
     except IncompatibleArguments as exc:
-        print(_(":: error: options {} can't be used together.").format(
+        print(translate(":: error: options {} can't be used together.").format(
             ", ".join([f"'--{opt}'" for opt in exc.args])
         ))
         sys.exit(1)
     except MissingArgument as exc:
         print(
-            _n(
+            translate_many(
                 ":: error: option {} can't be used without {}.",
                 ":: error: options {} can't be used without {}.",
                 len(exc.args[1:])
