@@ -304,14 +304,14 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
     def _compare_versions(self, compare_to: int) -> bool:
         local_db = PackageDB.get_local_dict()
         self.get_latest_dev_sources(check_dev_pkgs=self.args.needed)
-        return min([
+        return min(
             compare_versions(
                 local_db[pkg_name].version,
                 self.get_version(pkg_name)
             ) == compare_to
             if pkg_name in local_db else False
             for pkg_name in self.package_names
-        ])
+        )
 
     @property
     def version_already_installed(self) -> bool:
@@ -407,11 +407,14 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             PackageDB.discard_local_cache()
 
     def _set_built_package_path(self) -> None:
-        pkg_paths = spawn(
+        pkg_paths_spawn = spawn(
             isolate_root_cmd(MakePkgCommand.get() + ['--packagelist'],
                              cwd=self.build_dir),
             cwd=self.build_dir
-        ).stdout_text.splitlines()
+        )
+        if pkg_paths_spawn.returncode != 0:
+            return
+        pkg_paths = pkg_paths_spawn.stdout_text.splitlines()
         if not pkg_paths:
             return
         pkg_paths.sort(key=len)
