@@ -15,7 +15,7 @@ DEFAULT_CONFIG_ENCODING = 'utf-8'
 RUNNING_AS_ROOT = os.geteuid() == 0
 
 
-VERSION = '1.10.1-dev'
+VERSION = '1.11-dev'
 
 _USER_CACHE_HOME = os.environ.get(
     "XDG_CACHE_HOME",
@@ -49,7 +49,7 @@ else:
 if RUNNING_AS_ROOT:
     BUILD_DEPS_LOCK = os.path.join(_USER_CACHE_HOME, 'pikaur_build_deps.lock')
 else:
-    BUILD_DEPS_LOCK = '/tmp/pikaur_build_deps.lock'
+    BUILD_DEPS_LOCK = '/tmp/pikaur_build_deps.lock'  # nosec B108
 
 
 def get_config_path() -> str:
