@@ -11,7 +11,7 @@ from multiprocessing.pool import ThreadPool
 from time import sleep
 from typing import (
     TYPE_CHECKING,
-    Any, Callable, Iterable, List, Optional, Union, Tuple,
+    Any, Callable, Iterable, List, Optional, Union, Tuple, Dict,
 )
 
 import pyalpm
@@ -26,9 +26,6 @@ if TYPE_CHECKING:
     from .aur import AURPackageInfo  # noqa
 
 
-NOT_FOUND_ATOM = object()
-
-
 DEFAULT_INPUT_ENCODING = 'utf-8'
 
 
@@ -48,9 +45,7 @@ class ComparableType:
 
     def __eq__(self, other):
         if not isinstance(other, self.__class__):
-            raise TypeError(
-                f"'{other.__class__.__name__}' is not an instance of '{self.__class__.__name__}'"
-            )
+            return False
         if not self.__compare_stack__:
             self.__compare_stack__ = []
         elif other in self.__compare_stack__:
@@ -71,24 +66,33 @@ class ComparableType:
 
 class DataType(ComparableType):
 
-    def _key_not_exists(self, key):
-        return getattr(self, key, NOT_FOUND_ATOM) is NOT_FOUND_ATOM
+    @classmethod
+    @property
+    def __all_annotations__(cls) -> Dict[str, Any]:
+        annotations: Dict[str, Any] = {}
+        for parent_class in reversed(cls.mro()):
+            annotations.update(**getattr(parent_class, '__annotations__', {}))
+        return annotations
 
-    def __init__(self, **kwargs) -> None:
+    def _key_exists(self, key: str) -> bool:
+        return key in dir(self)
+
+    def __init__(self, **kwargs: Any) -> None:
         for key, value in kwargs.items():
             setattr(self, key, value)
-        for key in self.__annotations__:  # pylint: disable=no-member
-            if self._key_not_exists(key):
+        for key in self.__all_annotations__:
+            if not self._key_exists(key):
                 raise TypeError(
                     f"'{self.__class__.__name__}' does "
                     f"not have required attribute '{key}' set"
                 )
 
     def __setattr__(self, key: str, value: Any) -> None:
-        if (
-                not getattr(self, "__annotations__", None) or
-                self.__annotations__.get(key, NOT_FOUND_ATOM) is NOT_FOUND_ATOM  # pylint: disable=no-member
-        ) and self._key_not_exists(key):
+        if not (
+            (
+                key in self.__all_annotations__
+            ) or self._key_exists(key)
+        ):
             raise TypeError(
                 f"'{self.__class__.__name__}' does "
                 f"not have attribute '{key}'"
@@ -132,6 +136,14 @@ class InstallInfo(DataType):
         )
 
 
+class RepoInstallInfo(InstallInfo):
+    package: 'pyalpm.Package'
+
+
+class AURInstallInfo(InstallInfo):
+    package: 'AURPackageInfo'
+
+
 def sudo(cmd: List[str]) -> List[str]:
     if running_as_root():
         return cmd
@@ -206,7 +218,7 @@ def isolate_root_cmd(cmd: List[str], cwd=None) -> List[str]:
     if not running_as_root():
         return cmd
     base_root_isolator = [
-        'systemd-run',
+        '/usr/sbin/systemd-run',
         '--service-type=oneshot',
         '--pipe', '--wait', '--pty',
         '-p', 'DynamicUser=yes',
@@ -353,7 +365,7 @@ def run_with_sudo_loop(function: Callable) -> Optional[Any]:
 
 def check_systemd_dynamic_users() -> bool:  # pragma: no cover
     try:
-        out = subprocess.check_output(['systemd-run', '--version'],
+        out = subprocess.check_output(['/usr/sbin/systemd-run', '--version'],  # nosec B603
                                       universal_newlines=True)
     except FileNotFoundError:
         return False
