@@ -52,7 +52,7 @@ def debug(msg: Any) -> None:
 
 
 def hash_file(filename: str) -> str:  # pragma: no cover
-    md5 = hashlib.md5()
+    md5 = hashlib.new('md5', usedforsecurity=False)
     with open(filename, 'rb') as file:
         eof = False
         while not eof:
@@ -81,6 +81,7 @@ class InstallPackagesCLI():
     # User input
     args: PikaurArgs
     install_package_names: List[str]
+    # @TODO: define @property for manually_excluded_packages_names+args.ignore:
     manually_excluded_packages_names: List[str]
     resolved_conflicts: List[List[str]]
     # pkgbuild_path: [pkg_name, ...]  -- needed for split pkgs to install only some of them
@@ -250,7 +251,9 @@ class InstallPackagesCLI():
                 install_package_names=self.install_package_names,
                 not_found_repo_pkgs_names=self.not_found_repo_pkgs_names,
                 pkgbuilds_packagelists=self.pkgbuilds_packagelists,
-                manually_excluded_packages_names=self.manually_excluded_packages_names,
+                manually_excluded_packages_names=(
+                    self.manually_excluded_packages_names + self.args.ignore
+                ),
             )
         except PackagesNotFoundInAUR as exc:
             if exc.wanted_by:
@@ -275,6 +278,9 @@ class InstallPackagesCLI():
                 )
             )
             raise SysExit(131) from exc
+        except DependencyError as exc:
+            print_stderr(str(exc))
+            raise SysExit(131) from exc
 
         if self.args.repo and self.not_found_repo_pkgs_names:
             print_not_found_packages(self.not_found_repo_pkgs_names, repo=True)
@@ -287,7 +293,7 @@ class InstallPackagesCLI():
                     self.install_info.repo_packages_install_info +
                     self.install_info.new_repo_deps_install_info +
                     self.install_info.thirdparty_repo_packages_install_info +
-                    self.install_info.aur_updates_install_info
+                    self.install_info.aur_updates_install_info  # type: ignore[operator]
             ):
                 if (
                         # devel packages will be checked later
@@ -315,6 +321,7 @@ class InstallPackagesCLI():
         if not (
                 self.install_info.repo_packages_install_info or
                 self.install_info.new_repo_deps_install_info or
+                self.install_info.new_thirdparty_repo_deps_install_info or
                 self.install_info.thirdparty_repo_packages_install_info or
                 self.install_info.aur_updates_install_info
         ):
@@ -450,19 +457,20 @@ class InstallPackagesCLI():
             )
 
             aur_pkgs: List[AURPackageInfo] = [
-                info.package  # type: ignore[misc]
-                for container in self.install_info.all_install_info
+                info.package
+                for container in self.install_info.aur_install_info
                 for info in container
                 if info.name in pkgbuild.package_names
             ]
             aur_rpc_deps = set(
                 dep_line
                 for pkg in aur_pkgs
-                for dep_line in (
+                for matcher in (
                     pkg.depends +
                     pkg.makedepends +
                     pkg.checkdepends
                 )
+                for dep_line in matcher.split(',')
             )
 
             srcinfo_deps: Set[str] = set()
@@ -611,7 +619,8 @@ class InstallPackagesCLI():
             print_stderr(translate('looking for conflicting AUR packages...'))
             self.found_conflicts.update(
                 find_aur_conflicts(
-                    self.aur_packages_names + self.aur_deps_names,
+                    self.install_info.aur_updates_install_info +
+                    self.install_info.aur_deps_install_info,
                     self.install_package_names
                 )
             )
@@ -909,7 +918,6 @@ class InstallPackagesCLI():
         self.failed_to_build_package_names = failed_to_build_package_names
 
     def _remove_packages(self, packages_to_be_removed: List[str]) -> None:
-        # pylint: disable=no-self-use
         if packages_to_be_removed:
             retry_interactive_command_or_exit(
                 sudo(
