@@ -233,12 +233,12 @@ class PackageDBCommon():
                     ProvidedDependency(
                         name=pkg.name,
                         package=pkg,
-                        version_matcher=VersionMatcher(pkg.name)
+                        version_matcher=VersionMatcher(pkg.name, is_pkg_deps=True)
                     )
                 )
                 if pkg.provides:
                     for provided_pkg_line in pkg.provides:
-                        version_matcher = VersionMatcher(provided_pkg_line)
+                        version_matcher = VersionMatcher(provided_pkg_line, is_pkg_deps=True)
                         provided_name = version_matcher.pkg_name
                         provided_pkg_names.setdefault(provided_name, []).append(
                             ProvidedDependency(
@@ -392,9 +392,12 @@ class PackageDB(PackageDBCommon):
         if cached_pkg is not None:
             return cached_pkg
         results: List[PacmanPrint] = []
-        found_packages_output = spawn(
+        proc = spawn(
             cmd_args + ['--print-format', '%r/%n']
-        ).stdout_text
+        )
+        if proc.returncode != 0:
+            raise DependencyError(proc.stderr_text + proc.stdout_text)
+        found_packages_output = proc.stdout_text
         if found_packages_output:
             for line in found_packages_output.splitlines():
                 try:
@@ -487,11 +490,12 @@ class PackageDB(PackageDBCommon):
         if cls._pacman_repo_pkg_present_cache.get(pkg_name) is False:
             raise PackagesNotFoundInRepo(packages=[pkg_name])
         all_repo_pkgs = PackageDB.get_repo_dict()
-        results = cls.get_print_format_output(
-            get_pacman_command() + ['--sync'] + pkg_name.split(',')
-        )
-        if not results:
-            raise PackagesNotFoundInRepo(packages=[pkg_name])
+        try:
+            results = cls.get_print_format_output(
+                get_pacman_command() + ['--sync'] + pkg_name.split(',')
+            )
+        except DependencyError as exc:
+            raise PackagesNotFoundInRepo(packages=[pkg_name]) from exc
         found_pkgs = [all_repo_pkgs[result.full_name] for result in results]
         if len(results) == 1:
             return found_pkgs[0]
@@ -526,9 +530,14 @@ def find_upgradeable_packages() -> List[pyalpm.Package]:
         return []
 
     all_local_pkgs = PackageDB.get_local_dict()
-    results = PackageDB.get_print_format_output(
-        get_pacman_command() + ['--sync'] + pkg_names
-    )
+    results = []
+    for pkg_name in pkg_names:
+        try:
+            results += PackageDB.get_print_format_output(
+                get_pacman_command() + ['--sync'] + [pkg_name, ]
+            )
+        except DependencyError as exc:
+            print_stderr(str(exc))
     return [
         all_repo_pkgs[result.full_name] for result in results
         if result.name in all_local_pkgs
