@@ -18,7 +18,7 @@ from .args import parse_args
 from .exceptions import AURError, SysExit
 
 
-SamePackageType = TypeVar('SamePackageType', AURPackageInfo, pyalpm.Package)
+SamePackageTypeT = TypeVar('SamePackageTypeT', AURPackageInfo, pyalpm.Package)
 
 
 def package_search_thread_repo(query: str) -> List[pyalpm.Package]:
@@ -46,7 +46,7 @@ def filter_aur_results(
     return filtered_results
 
 
-def package_search_thread_aur(queries: List[str]) -> Dict[str, List[Any]]:  # pylint: disable=too-many-branches
+def package_search_thread_aur(queries: List[str]) -> List[Any]:  # pylint: disable=too-many-branches
     args = parse_args()
     result = {}
     if queries:
@@ -98,7 +98,7 @@ def package_search_thread_aur(queries: List[str]) -> Dict[str, List[Any]]:  # py
             result = {'all': get_all_aur_packages()}
     if not args.quiet:
         sys.stderr.write('#')
-    return result
+    return list(join_search_results(list(result.values())))
 
 
 def package_search_thread_local() -> Dict[str, str]:
@@ -112,8 +112,10 @@ def package_search_thread_local() -> Dict[str, str]:
 
 
 def join_search_results(
-        all_search_results: List[List[SamePackageType]]
-) -> Iterable[SamePackageType]:
+        all_search_results: List[List[SamePackageTypeT]]
+) -> Iterable[SamePackageTypeT]:
+    if not all_search_results:
+        return []
     pkgnames_set: Set[str] = set()
     for search_results in all_search_results:
         new_pkgnames_set = set(get_pkg_id(result) for result in search_results)
@@ -173,9 +175,7 @@ def cli_search_packages(enumerated=False) -> List[AnyPackage]:  # pylint: disabl
     joined_repo_results: Iterable[pyalpm.Package] = []
     if result_repo:
         joined_repo_results = join_search_results(result_repo)
-    joined_aur_results: Iterable[AURPackageInfo] = []
-    if result_aur:
-        joined_aur_results = join_search_results(list(result_aur.values()))
+    joined_aur_results: Iterable[AURPackageInfo] = result_aur or []
 
     return print_package_search_results(
         repo_packages=joined_repo_results,
