@@ -23,7 +23,7 @@ def read_bytes_from_url(url: str, optional=False) -> bytes:
         )
     req = request.Request(url, headers={'User-Agent': 'Mozilla/5.0'})
     try:
-        with request.urlopen(req) as response:
+        with request.urlopen(req) as response:  # nosec B310
             result_bytes = response.read()
             return result_bytes
     except URLError as exc:
@@ -76,7 +76,7 @@ def init_proxy() -> None:
             socks_proxy_addr = socks_proxy_addr[:idx]
 
         try:
-            import socks  # type: ignore[import]  # pylint:disable=import-outside-toplevel
+            import socks  # type: ignore[import]  # pylint: disable=import-outside-toplevel
         except ImportError as exc:
             raise ProxyInitSocks5Error(
                 translate("pikaur requires python-pysocks to use a socks5 proxy.")
